@@ -27,6 +27,18 @@
 --
 --
 -- $Log: disk_io.c,v $
+-- Revision 1.81  2008/05/05 12:41:15  jsedwards
+-- Changed so that if fopen of index file fails that it just prints a warning
+-- and continues without writing the index file.
+--
+-- Revision 1.80  2008/05/05 12:15:33  jsedwards
+-- Fix Bug #1957451 - added test to make sure fopen didn't return NULL before
+-- calling fwrite for index file.
+--
+-- Revision 1.79  2008/04/13 23:06:57  jsedwards
+-- Changed to conditionally use gettimeofday instead of clock_gettime if the
+-- OS doesn't support it (like Mac OS X).
+--
 -- Revision 1.78  2008/04/02 03:06:21  jsedwards
 -- Added file locking.
 --
@@ -550,27 +562,37 @@ void index_compressed_file()
 	    perror(nwos_private_path);
 	    exit(1);
 	}
-#ifndef NO_INDEX_FILE
-	fprintf(stderr, "Writing index file: %s\n", index_path);
 
+#ifndef NO_INDEX_FILE
 	index_fp = fopen(index_path, "w");
 
-	if (fwrite(header, 1, sizeof(header), index_fp) != sizeof(header))
+	if (index_fp == NULL)
 	{
+	    fprintf(stderr, "Could not create index file: ");
 	    perror(index_path);
-	    exit(1);
+	    fprintf(stderr, "Index will not be saved!\n");
 	}
-
-	if (fwrite(&storage_index[1], sizeof(ObjRef), i, index_fp) != i)
+	else
 	{
-	    perror(index_path);
-	    exit(1);
-	}
+	    fprintf(stderr, "Writing index file: %s\n", index_path);
 
-	if (fclose(index_fp))
-	{
-	    perror(index_path);
-	    exit(1);
+	    if (fwrite(header, 1, sizeof(header), index_fp) != sizeof(header))
+	    {
+		perror(index_path);
+		exit(1);
+	    }
+
+	    if (fwrite(&storage_index[1], sizeof(ObjRef), i, index_fp) != i)
+	    {
+		perror(index_path);
+		exit(1);
+	    }
+
+	    if (fclose(index_fp))
+	    {
+		perror(index_path);
+		exit(1);
+	    }
 	}
 #endif
     }
@@ -591,10 +613,17 @@ void index_compressed_file()
 
 void initialize_random_number_generator()
 {
+#ifdef HAVE_CLOCK_GETTIME
     struct timespec ts;
 
     clock_gettime(CLOCK_REALTIME, &ts);
     srandom((uint32)ts.tv_sec ^ (uint32)ts.tv_nsec);
+#else
+    struct timeval tv;
+
+    gettimeofday(&tv, NULL);
+    srandom((uint32)tv.tv_sec ^ (uint32)tv.tv_usec);
+#endif
 
 #ifdef DISABLE_SECURITY_FEATURES
     randomxxx = 0x00000100;     /* start objects here */
