@@ -27,6 +27,11 @@
 --
 --
 -- $Log: export_file.c,v $
+-- Revision 1.19  2008/03/09 15:41:12  jsedwards
+-- Added code to create subdirectories if they don't exist.  (File changed on
+-- laptop on 2008/02/29 in Columbia, South Carolina but could not check in
+-- because didn't have Internet access).
+--
 -- Revision 1.18  2008/02/03 01:04:28  jsedwards
 -- Changed DEFAULT_TYPE_RO to READ_ONLY and changed path variable to const char
 -- instead of char.
@@ -113,11 +118,12 @@
 --
 */
 
-
+#include <errno.h>
 #include <fnmatch.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <sys/stat.h>
 #include "objectify.h"
 
 
@@ -138,6 +144,7 @@ void export_file(char* name)
     C_struct_File file_obj;
     C_struct_Path_And_File_Association assoc_obj;
     int num_files;
+    char* p;
 
     printf("%s: ", name);
     fflush(stdout);
@@ -165,7 +172,20 @@ void export_file(char* name)
 		printf("not stored in system\n");
 	    }
 	    else
-	    {
+	      {
+		p = strchr(name, '/');
+		while (p != NULL)
+		{
+		    *p = '\0';
+		    if (mkdir(name, 0755) != 0 && errno != EEXIST)
+		    {
+			perror(p);
+		    }
+		    *p = '/';
+
+		    p = strchr(p + 1, '/');
+		}
+
 		result = nwos_restore_file(&assoc_ref, name);
 
 		if (result)
