@@ -27,6 +27,9 @@
 --
 --
 -- $Log: list_files.c,v $
+-- Revision 1.26  2008/04/09 12:35:21  jsedwards
+-- Added call to nwos_log_arguments to disable logging.
+--
 -- Revision 1.25  2008/03/14 19:11:19  jsedwards
 -- Added --sha512 option.
 --
@@ -285,6 +288,8 @@ int main(int argc, char* argv[])
     bool match;
 
 
+    nwos_log_arguments(0, NULL);   /* disable logging */
+
     char* path = DEFAULT_FILE;
 
     argn = 1;
