@@ -27,6 +27,11 @@
 --
 --
 -- $Log: objectify.c,v $
+-- Revision 1.149  2008/05/06 13:31:03  jsedwards
+-- Changed return type of nwos_read_object_from_disk_and_decrypt to bool
+-- instead of void and changed it to return false if the block read fails.
+-- Added assert around calls to nwos_read_object_from_disk_and_decrypt.
+--
 -- Revision 1.148  2008/03/20 13:13:50  jsedwards
 -- Added nwos_in_public_mode function.
 --
@@ -1438,7 +1443,7 @@ void compare_bufs(uint8 buf1[FILE_BLOCK_SIZE], uint8 buf2[FILE_BLOCK_SIZE], char
 #endif
 
 
-void nwos_read_object_from_disk_and_decrypt(ObjRef* ref, void* object, size_t size, uint8 ivec[IVEC_SIZE], uint8 seq_table[FILE_BLOCK_SIZE])
+bool nwos_read_object_from_disk_and_decrypt(ObjRef* ref, void* object, size_t size, uint8 ivec[IVEC_SIZE], uint8 seq_table[FILE_BLOCK_SIZE])
 {
     uint8 buffer2[FILE_BLOCK_SIZE];
 #ifndef PUBLIC_MODE
@@ -1447,62 +1452,66 @@ void nwos_read_object_from_disk_and_decrypt(ObjRef* ref, void* object, size_t si
     int i;
     int j;
 #endif
+    bool result = false;
 
     assert(!is_void_reference(ref));
 
-    assert(nwos_read_block(ref, buffer2));
-
-    assert(block_contains_object(buffer2, ref));
+    if (nwos_read_block(ref, buffer2))
+    {
+	assert(block_contains_object(buffer2, ref));
 #ifdef PUBLIC_MODE
-    memcpy(object, buffer2, size);
+	memcpy(object, buffer2, size);
 #else
 #ifdef DEBUG_ENCRYPTION
-    compare_bufs(buffer2, save_encrypted, "Encrypted");
+	compare_bufs(buffer2, save_encrypted, "Encrypted");
 #endif
 
 #ifdef DISABLE_SECURITY_FEATURES
-    if (true)
+	if (true)
 #else
-    if (nwos_reference_type(ref) == Public_Reference)
+	if (nwos_reference_type(ref) == Public_Reference)
 #endif
-    {
-	memcpy(object, buffer2, size);    /* just copy the buffer into the object */
-    }
-    else
-    {
-	/* copy the first 8 bytes directly, not encrypted */
-	memcpy(buffer1, buffer2, 8);
+	{
+	    memcpy(object, buffer2, size);    /* just copy the buffer into the object */
+	}
+	else
+	{
+	    /* copy the first 8 bytes directly, not encrypted */
+	    memcpy(buffer1, buffer2, 8);
 
-	/* decrypt the remaining bytes */
-	BF_cbc_encrypt((buffer2 + 8), (buffer1 + 8), (FILE_BLOCK_SIZE - 8), &blowfish_key, ivec, BF_DECRYPT);
+	    /* decrypt the remaining bytes */
+	    BF_cbc_encrypt((buffer2 + 8), (buffer1 + 8), (FILE_BLOCK_SIZE - 8), &blowfish_key, ivec, BF_DECRYPT);
 
 #if 0
-	printf("ivec: ");
-	for (i = 0; i < 8; i++) printf("%02x ", ivec[i]);
-	printf("\n");
+	    printf("ivec: ");
+	    for (i = 0; i < 8; i++) printf("%02x ", ivec[i]);
+	    printf("\n");
 #endif
 
 #ifdef DEBUG_ENCRYPTION
-	compare_bufs(buffer1, save_mixed_up, "Mixed up");
+	    compare_bufs(buffer1, save_mixed_up, "Mixed up");
 #endif
 
-	assert(size <= FILE_BLOCK_SIZE);
+	    assert(size <= FILE_BLOCK_SIZE);
 
-	/* copy the first 8 bytes directly accross */
-	for (i = 0; i < 8; i++) ptrobj[i] = buffer1[i];
+	    /* copy the first 8 bytes directly accross */
+	    for (i = 0; i < 8; i++) ptrobj[i] = buffer1[i];
 
-	for (i = 8; i < size; i++)
-	{
-	    j = seq_table[i];    /* find where the next byte is stored */
-	    ptrobj[i] = buffer1[j];    /* get this byte from there */
+	    for (i = 8; i < size; i++)
+	    {
+		j = seq_table[i];    /* find where the next byte is stored */
+		ptrobj[i] = buffer1[j];    /* get this byte from there */
+	    }
 	}
 
+#ifdef DEBUG_ENCRYPTION
+	compare_bufs(ptrobj, save_unencrypted, "Unencrypted");
+#endif
+#endif
+	result = true;
     }
 
-#ifdef DEBUG_ENCRYPTION
-    compare_bufs(ptrobj, save_unencrypted, "Unencrypted");
-#endif
-#endif
+    return result;
 }
 
 
@@ -1673,7 +1682,7 @@ void nwos_read_object_from_disk(ObjRef* ref, void* object, size_t size)
 
     ptr_obj = object;
 
-    nwos_read_object_from_disk_and_decrypt(ref, &extra, sizeof(extra), ivec, nwos_random_sequence[seq]);
+    assert(nwos_read_object_from_disk_and_decrypt(ref, &extra, sizeof(extra), ivec, nwos_random_sequence[seq]));
 
     assert(sizeof(ObjRef) == 4);
 
@@ -1699,7 +1708,7 @@ void nwos_read_object_from_disk(ObjRef* ref, void* object, size_t size)
 
 	seq++;
 
-	nwos_read_object_from_disk_and_decrypt(&next_ref, &extra, sizeof(extra), ivec, nwos_random_sequence[seq]);
+	assert(nwos_read_object_from_disk_and_decrypt(&next_ref, &extra, sizeof(extra), ivec, nwos_random_sequence[seq]));
     }
 
     assert(bytes_remaining <= FILE_BLOCK_SIZE);
@@ -1770,7 +1779,7 @@ void nwos_read_variable_sized_object_from_disk(ObjRef* ref, void* object, size_t
 
     ptr_obj = object;
 
-    nwos_read_object_from_disk_and_decrypt(ref, &extra, sizeof(extra), ivec, nwos_random_sequence[seq]);
+    assert(nwos_read_object_from_disk_and_decrypt(ref, &extra, sizeof(extra), ivec, nwos_random_sequence[seq]));
 
     assert(sizeof(ObjRef) == 4);
 
@@ -1809,7 +1818,7 @@ void nwos_read_variable_sized_object_from_disk(ObjRef* ref, void* object, size_t
 
 	seq++;
 
-	nwos_read_object_from_disk_and_decrypt(&next_ref, &extra, sizeof(extra), ivec, nwos_random_sequence[seq]);
+	assert(nwos_read_object_from_disk_and_decrypt(&next_ref, &extra, sizeof(extra), ivec, nwos_random_sequence[seq]));
     }
 
     assert(bytes_remaining <= FILE_BLOCK_SIZE);
@@ -1843,7 +1852,7 @@ void nwos_read_object_headers_from_disk(ObjRef* ref, EveryObject* header)
     assert(!is_void_reference(ref));
 
     memset(ivec, 0, sizeof(ivec));
-    nwos_read_object_from_disk_and_decrypt(ref, header, sizeof(*header), ivec, nwos_random_sequence[0]);
+    assert(nwos_read_object_from_disk_and_decrypt(ref, header, sizeof(*header), ivec, nwos_random_sequence[0]));
 
 #if 0
     printf("read header path: %s\n", path);
@@ -2051,7 +2060,7 @@ void nwos_get_object_class_without_update(ObjRef* obj, ObjRef* object_class)
 
     memset(ivec, 0, sizeof(ivec));
 
-    nwos_read_object_from_disk_and_decrypt(obj, &header, sizeof(header), ivec, nwos_random_sequence[0]);
+    assert(nwos_read_object_from_disk_and_decrypt(obj, &header, sizeof(header), ivec, nwos_random_sequence[0]));
 
     check_common_header(obj, &header.common);
 
