@@ -27,6 +27,10 @@
 --
 --
 -- $Log: objectify_private.h,v $
+-- Revision 1.65  2008/05/06 13:28:51  jsedwards
+-- Changed return type of nwos_read_object_from_disk_and_decrypt to bool
+-- instead of void.
+--
 -- Revision 1.64  2008/03/14 12:16:26  jsedwards
 -- Added external reference for nwos_update_file_002_object_to_current.
 --
@@ -469,7 +473,7 @@ extern void nwos_flush_dirty_ref_lists();
 extern void nwos_create_public_acronym(char* acronym, ObjRef* ref);
 extern uint32 nwos_next_sequence(uint32* linear_seed, uint32* serial_seed);
 
-extern void nwos_read_object_from_disk_and_decrypt(ObjRef* ref, void* object, size_t size, uint8 ivec[IVEC_SIZE], uint8 seq_table[FILE_BLOCK_SIZE]);
+extern bool nwos_read_object_from_disk_and_decrypt(ObjRef* ref, void* object, size_t size, uint8 ivec[IVEC_SIZE], uint8 seq_table[FILE_BLOCK_SIZE]);
 extern void nwos_write_object_to_disk_and_encrypt(ObjRef* ref, void* object, size_t size, uint8 ivec[IVEC_SIZE], uint8 seq_table[FILE_BLOCK_SIZE]);
 
 extern const char* nwos_public_path;
