@@ -1,6 +1,6 @@
 /*
 --             This file is part of the New World OS project
---                 Copyright (C) 2004-2007  QRW Software
+--                 Copyright (C) 2004-2008  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
@@ -27,6 +27,10 @@
 --
 --
 -- $Log: time_stamp.c,v $
+-- Revision 1.8  2008/04/13 23:24:26  jsedwards
+-- Added conditional code to use gettimeofday instead of clock_gettime because
+-- some OSes (like Mac OS X) don't have clock_gettime.
+--
 -- Revision 1.7  2007/07/01 19:44:12  jsedwards
 -- Upgrade to GPLv3.
 --
@@ -130,12 +134,20 @@ static void timestamp_to_unix_broken_down_time(uint8 stamp[8], struct tm* bdt, u
 void nwos_get_time_stamp(TimeStamp stamp)
 {
   struct timespec ts;
-
+#ifdef HAVE_CLOCK_GETTIME
   if (clock_gettime(CLOCK_REALTIME, &ts) != 0) {
     perror("reading real-time clock");
     exit(1);
   }
-
+#else
+  struct timeval tv;
+  if (gettimeofday(&tv, NULL) != 0) {
+    perror("reading real-time clock");
+    exit(1);
+  }
+  ts.tv_sec = tv.tv_sec;
+  ts.tv_nsec = tv.tv_usec * 1000;
+#endif
   nwos_convert_timespec_to_time_stamp(&ts, stamp);
 }
 
